@@ -26,7 +26,6 @@ from collections import OrderedDict
 from collections.abc import MutableMapping
 from math import floor
 
-from botocore.vendored import six
 from botocore.exceptions import MD5UnavailableError
 from dateutil.tz import tzlocal
 from urllib3 import exceptions
@@ -70,8 +69,6 @@ def set_socket_timeout(http_response, timeout):
     http_response._fp.fp.raw._sock.settimeout(timeout)
 
 def accepts_kwargs(func):
-    # In python3.4.1, there's backwards incompatible
-    # changes when using getargspec with functools.partials.
     return inspect.getfullargspec(func)[2]
 
 def ensure_unicode(s, encoding=None, errors=None):
@@ -86,12 +83,9 @@ def ensure_bytes(s, encoding='utf-8', errors='strict'):
     raise ValueError(f"Expected str or bytes, received {type(s)}.")
 
 
-try:
-    import xml.etree.cElementTree as ETree
-except ImportError:
-    # cElementTree does not exist from Python3.9+
-    import xml.etree.ElementTree as ETree
+import xml.etree.ElementTree as ETree
 XMLParseError = ETree.ParseError
+
 import json
 
 
